@@ -117,7 +117,7 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
   return method_get_handler, request_handler
 
 
-async def start_gateway(descriptor: FileDescriptor, shutdown_trigger, port: int = 7070):
+async def start_gateway(descriptor: FileDescriptor, port: int = 7070):
   logging.info('starting gateway...')
   debug = 'DELPHAI_ENVIRONMENT' in os.environ and os.environ['DELPHAI_ENVIRONMENT'] == 'development'
   app = Starlette(debug=debug, exception_handlers={HTTPException: http_exception})
@@ -151,4 +151,4 @@ async def start_gateway(descriptor: FileDescriptor, shutdown_trigger, port: int
               if http_path != '':
                 app.add_route(http_path, route=request_handler, methods=[supported_method])
   logging.info(f'started gateway on port {port}')
-  return await serve(app, config, shutdown_trigger=shutdown_trigger)
+  return await serve(app, config)
