@@ -30,16 +30,16 @@ def create_grpc_server(descriptor: FileDescriptor):
   return server
 
 
-async def start_server(server: Server, gateway: bool = True):
+def start_server(server: Server, gateway: bool = True):
   logging.info('starting grpc server...')
-  await server.start()
-  logging.info('started grpc server on port 8080')
   loop = asyncio.get_event_loop()
+  loop.run_until_complete(server.start())
+  logging.info('started grpc server on port 8080')
   try:
     if gateway:
       gateway = start_gateway(server.__dict__['descriptor'])
       loop.create_task(gateway)
     loop.create_task(server.wait_for_termination())
-    loop.wait_for_termination()
+    loop.run_forever()
   except KeyboardInterrupt:
-    logging.info('stopped server (keyboard interrupt)')
+    logging.info('stopped server (keyboard interrupt)')
\ No newline at end of file
